import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { CustomerInfoVO, CustomerInfoForm, CustomerInfoQuery } from '@/api/system/customerInfo/types';

/**
 * 查询客户信息列表
 * @param query
 * @returns {*}
 */

export const listCustomerInfo = (query?: CustomerInfoQuery): AxiosPromise<CustomerInfoVO[]> => {
  return request({
    url: '/system/customerInfo/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询客户信息详细
 * @param id
 */
export const getCustomerInfo = (id: string | number): AxiosPromise<CustomerInfoVO> => {
  return request({
    url: '/system/customerInfo/' + id,
    method: 'get'
  });
};

/**
 * 新增客户信息
 * @param data
 */
export const addCustomerInfo = (data: CustomerInfoForm) => {
  return request({
    url: '/system/customerInfo',
    method: 'post',
    data: data
  });
};

/**
 * 修改客户信息
 * @param data
 */
export const updateCustomerInfo = (data: CustomerInfoForm) => {
  return request({
    url: '/system/customerInfo',
    method: 'put',
    data: data
  });
};

/**
 * 删除客户信息
 * @param id
 */
export const delCustomerInfo = (id: string | number | Array<string | number>) => {
  return request({
    url: '/system/customerInfo/' + id,
    method: 'delete'
  });
};
