import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { MaterialSealVO, MaterialSealForm, MaterialSealQuery } from '@/api/operate/materialSeal/types';

/**
 * 查询公章管理列表
 * @param query
 * @returns {*}
 */

export const listMaterialSeal = (query?: MaterialSealQuery): AxiosPromise<MaterialSealVO[]> => {
  return request({
    url: '/operate/materialSeal/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询公章管理详细
 * @param id
 */
export const getMaterialSeal = (id: string | number): AxiosPromise<MaterialSealVO> => {
  return request({
    url: '/operate/materialSeal/' + id,
    method: 'get'
  });
};

/**
 * 新增公章管理
 * @param data
 */
export const addMaterialSeal = (data: MaterialSealForm) => {
  return request({
    url: '/operate/materialSeal',
    method: 'post',
    data: data
  });
};

/**
 * 修改公章管理
 * @param data
 */
export const updateMaterialSeal = (data: MaterialSealForm) => {
  return request({
    url: '/operate/materialSeal',
    method: 'put',
    data: data
  });
};

/**
 * 删除公章管理
 * @param id
 */
export const delMaterialSeal = (id: string | number | Array<string | number>) => {
  return request({
    url: '/operate/materialSeal/' + id,
    method: 'delete'
  });
};

/**
 * 公章状态修改
 */
export const changeSealStatus = (id: string | number, sealStatus: string) => {
  const data = {
    id,
    sealStatus
  };
  return request({
    url: '/operate/materialSeal/changeStatus',
    method: 'put',
    data: data
  });
};
