import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { BusinessTripVO, BusinessTripQuery, BusinessTripForm } from '@/api/workflow/businessTrip/types';

/**
 * 查询出差列表
 * @param query
 * @returns {*}
 */

export const listBusinessTrip = (query?: BusinessTripQuery): AxiosPromise<BusinessTripVO[]> => {
  return request({
    url: '/workflow/businessTrip/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询出差详细
 * @param id
 */
export const getBusinessTrip = (id: string | number): AxiosPromise<BusinessTripVO> => {
  return request({
    url: '/workflow/businessTrip/' + id,
    method: 'get'
  });
};

/**
 * 新增出差
 * @param data
 */
export const addBusinessTrip = (data: BusinessTripForm): AxiosPromise<BusinessTripVO> => {
  return request({
    url: '/workflow/businessTrip',
    method: 'post',
    data: data
  });
};

/**
 * 修改出差
 * @param data
 */
export const updateBusinessTrip = (data: BusinessTripForm): AxiosPromise<BusinessTripVO> => {
  return request({
    url: '/workflow/businessTrip',
    method: 'put',
    data: data
  });
};

/**
 * 删除出差
 * @param id
 */
export const delBusinessTrip = (id: string | number | Array<string | number>) => {
  return request({
    url: '/workflow/businessTrip/' + id,
    method: 'delete'
  });
};
