import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { SealVO, SealQuery, SealForm } from '@/api/workflow/seal/types';

/**
 * 查询用章列表
 * @param query
 * @returns {*}
 */

export const listSeal = (query?: SealQuery): AxiosPromise<SealVO[]> => {
  return request({
    url: '/workflow/seal/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询用章详细
 * @param id
 */
export const getSeal = (id: string | number): AxiosPromise<SealVO> => {
  return request({
    url: '/workflow/seal/' + id,
    method: 'get'
  });
};

/**
 * 新增用章
 * @param data
 */
export const addSeal = (data: SealForm): AxiosPromise<SealVO> => {
  return request({
    url: '/workflow/seal',
    method: 'post',
    data: data
  });
};

/**
 * 修改用章
 * @param data
 */
export const updateSeal = (data: SealForm): AxiosPromise<SealVO> => {
  return request({
    url: '/workflow/seal',
    method: 'put',
    data: data
  });
};

/**
 * 删除用章
 * @param id
 */
export const delSeal = (id: string | number | Array<string | number>) => {
  return request({
    url: '/workflow/seal/' + id,
    method: 'delete'
  });
};
